@@ -1,6 +1,6 @@
 from collections import defaultdict
 from functools import reduce
-
+import json
 import singer
 from singer import Catalog, CatalogEntry, Schema, metadata
 from singer.catalog import write_catalog
@@ -127,8 +127,13 @@ def generate_catalog(reports, dimensions, metrics, field_exclusions):
 
 def get_field_exclusions(client, property_id, dimensions, metrics):
     field_exclusions = defaultdict(list)
+    with open("field_exclusions.json", "r", encoding="utf-8") as infile:
+        field_exclusions.update(json.load(infile))
+
     LOGGER.info("Discovering dimension field exclusions")
     for dimension in dimensions:
+        if dimension.api_name in field_exclusions:
+            continue
         res = client.check_dimension_compatibility(property_id, dimension)
         for field in res.dimension_compatibilities:
             field_exclusions[dimension.api_name].append(
@@ -139,6 +144,8 @@ def get_field_exclusions(client, property_id, dimensions, metrics):
 
     LOGGER.info("Discovering metric field exclusions")
     for metric in metrics:
+        if metric.api_name in field_exclusions:
+            continue
         res = client.check_metric_compatibility(property_id, metric)
         for field in res.dimension_compatibilities:
             field_exclusions[metric.api_name].append(field.dimension_metadata.api_name)
